Documentation from Docstrings
*****************************

This documentation is automatically generated from the docstrings using the 'autodoc' extension for Sphinx. The
numpydoc formatting is followed.

.. automodule:: steel_toolbox

en_tools module: Eurocode calculations
======================================
.. automodule:: en_tools
   :members:

abq_tools module: Tools for Abaqus cae
======================================
.. automodule:: abq_tools
   :members:

parametric_tools module: Manage parametric jobs
========================================
.. automodule:: parametric_tools
   :members:

steel_tools module: Tools for steel design
===================================
.. automodule:: steel_tools
   :members:
